==> adrien-portage-0.1.0.tar.gz: adrien-portage-0.1.0/lib/puppet/type/package_keywords.rb <==
require 'puppet/util/portage'
Puppet::Type.newtype(:package_keywords) do
  @doc = "Set keywords for a package.

      package_keywords { 'app-admin/puppet':
        keywords  => ['~x86', '-hppa'],
        target  => 'puppet',
      }"

  ensurable

  newparam(:name) do
    desc "The package name"

    isnamevar

    validate do |value|
      unless Puppet::Util::Portage.valid_atom? value
        raise Puppet::Error, "name must be a properly formatted atom, see man portage(5) for more information"
      end
    end
  end

  newproperty(:keywords) do
    desc "The keywords(s) to use"

    validate do |value|
      raise Puppet::Error, "Keyword cannot contain whitespace" if value =~ /\s/
    end

    def insync?(is)
      is == @should
    end

    def should
      if defined? @should
        if @should == [:absent]
          return :absent
        else
          return @should
        end
      else
        return nil
      end
    end

    def should_to_s(newvalue = @should)
      newvalue.join(" ")
    end

    def is_to_s(currentvalue = @is)
      currentvalue = [currentvalue] unless currentvalue.is_a? Array
      currentvalue.join(" ")
    end

  end

  newproperty(:target) do
    desc "The location of the package.keywords file"

    defaultto do
      if @resource.class.defaultprovider.ancestors.include?(Puppet::Provider::ParsedFile)
        @resource.class.defaultprovider.default_target
      else
        nil
      end
    end

    # Allow us to not have to specify an absolute path unless we really want to
    munge do |value|
      if !value.match(/\//)
        value = "/etc/portage/package.keywords/" + value
      end
      value
    end
  end
end

==> adrien-portage-2.0.0-rc1.tar.gz: adrien-portage-2.0.0-rc1/lib/puppet/type/package_keywords.rb <==
require 'puppet/util/portage'
Puppet::Type.newtype(:package_keywords) do
  @doc = "Set keywords for a package.

      package_keywords { 'app-admin/puppet':
        keywords  => ['~x86', '-hppa'],
        target  => 'puppet',
      }"

  ensurable do
    defaultvalues
    defaultto :present
  end

  newparam(:name) do
    desc "The package name"

    isnamevar

    validate do |value|
      unless Puppet::Util::Portage.valid_package? value
        raise ArgumentError, "name must be a properly formatted atom, see man portage(5) for more information"
      end
    end
  end

  newproperty(:version) do
    desc "A properly formatted version string"

    validate do |value|
      unless Puppet::Util::Portage.valid_version? value
        raise ArgumentError, "name must be a properly formatted version"
      end
    end
  end

  newproperty(:keywords) do
    desc "The keywords(s) to use"

    validate do |value|
      raise ArgumentError, "Keyword cannot contain whitespace" if value =~ /\s/
    end

    def insync?(is)
      is == @should
    end

    def should
      if defined? @should
        if @should == [:absent]
          return :absent
        else
          return @should
        end
      else
        return nil
      end
    end

    def should_to_s(newvalue = @should)
      newvalue.join(" ")
    end

    def is_to_s(currentvalue = @is)
      currentvalue = [currentvalue] unless currentvalue.is_a? Array
      currentvalue.join(" ")
    end

  end

  newproperty(:target) do
    desc "The location of the package.keywords file"

    defaultto do
      if @resource.class.defaultprovider.ancestors.include?(Puppet::Provider::ParsedFile)
        @resource.class.defaultprovider.default_target
      else
        nil
      end
    end

    # Allow us to not have to specify an absolute path unless we really want to
    munge do |value|
      if !value.match(/\//)
        value = "/etc/portage/package.keywords/" + value
      end
      value
    end
  end
end
